pub struct BoundedI8<const MIN: i8, const MAX: i8>(/* private fields */);Expand description
An
i8
constrained to be in the range MIN..=MAX.
Implementations
Sourceimpl<const MIN: i8, const MAX: i8> BoundedI8<MIN, MAX>
impl<const MIN: i8, const MAX: i8> BoundedI8<MIN, MAX>
Sourcepub const fn const_new<const N: i8>() -> Self
pub const fn const_new<const N: i8>() -> Self
Creates a bounded integer whose value is known at compile time.
Causes a compile-time error if N is not in the valid range.
Sourcepub const unsafe fn new_unchecked(n: i8) -> Self
pub const unsafe fn new_unchecked(n: i8) -> Self
Sourcepub const unsafe fn new_ref_unchecked(n: &i8) -> &Self
pub const unsafe fn new_ref_unchecked(n: &i8) -> &Self
Sourcepub const unsafe fn new_mut_unchecked(n: &mut i8) -> &mut Self
pub const unsafe fn new_mut_unchecked(n: &mut i8) -> &mut Self
Sourcepub const fn in_range(n: i8) -> bool
pub const fn in_range(n: i8) -> bool
Checks whether the given value is in the range of the bounded integer.
Sourcepub const fn new_saturating(n: i8) -> Self
pub const fn new_saturating(n: i8) -> Self
Sourcepub const fn new_wrapping<__Z: LargerInt>(n: __Z) -> Self
pub const fn new_wrapping<__Z: LargerInt>(n: __Z) -> Self
Creates a bounded integer by wrapping using modular arithmetic.
For n in range, this is an identity function, and it wraps for n out of range.
The type parameter Z must be any integer type that is a superset of this one.
Sourcepub const fn from_str_radix(src: &str, radix: u32) -> Result<Self, ParseError>
pub const fn from_str_radix(src: &str, radix: u32) -> Result<Self, ParseError>
Converts a string slice in a given base to the bounded integer.
Panics
Panics if radix is below 2 or above 36.
Sourcepub const fn get_ref(&self) -> &i8
pub const fn get_ref(&self) -> &i8
Returns a shared reference to the value of the bounded integer.
Sourcepub const unsafe fn get_mut(&mut self) -> &mut i8
pub const unsafe fn get_mut(&mut self) -> &mut i8
Returns a mutable reference to the value of the bounded integer.
Safety
This value must never be set to a value beyond the range of the bounded integer.
Sourcepub const fn abs(self) -> Self
pub const fn abs(self) -> Self
Computes the absolute value of self, panicking if it is out of range.
Sourcepub const fn pow(self, exp: u32) -> Self
pub const fn pow(self, exp: u32) -> Self
Raises self to the power of exp, using exponentiation by squaring. Panics if it
is out of range.
Sourcepub const fn div_euclid(self, rhs: i8) -> Self
pub const fn div_euclid(self, rhs: i8) -> Self
Calculates the quotient of Euclidean division of self by rhs. Panics if rhs
is 0 or the result is out of range.
Sourcepub const fn rem_euclid(self, rhs: i8) -> Self
pub const fn rem_euclid(self, rhs: i8) -> Self
Calculates the least nonnegative remainder of self (mod rhs). Panics if rhs is 0
or the result is out of range.
Sourcepub const fn checked_add(self, rhs: i8) -> Option<Self>
pub const fn checked_add(self, rhs: i8) -> Option<Self>
Checked integer addition.
Returns None if the result would be out of range.
Sourcepub const fn saturating_add(self, rhs: i8) -> Self
pub const fn saturating_add(self, rhs: i8) -> Self
Saturating integer addition.
Sourcepub const fn wrapping_add(self, rhs: i8) -> Self
pub const fn wrapping_add(self, rhs: i8) -> Self
Wrapping (modular) integer addition.
Sourcepub const fn checked_sub(self, rhs: i8) -> Option<Self>
pub const fn checked_sub(self, rhs: i8) -> Option<Self>
Checked integer subtraction.
Returns None if the result would be out of range.
Sourcepub const fn saturating_sub(self, rhs: i8) -> Self
pub const fn saturating_sub(self, rhs: i8) -> Self
Saturating integer subtraction.
Sourcepub const fn wrapping_sub(self, rhs: i8) -> Self
pub const fn wrapping_sub(self, rhs: i8) -> Self
Wrapping (modular) integer subtraction.
Sourcepub const fn checked_mul(self, rhs: i8) -> Option<Self>
pub const fn checked_mul(self, rhs: i8) -> Option<Self>
Checked integer multiplication.
Returns None if the result would be out of range.
Sourcepub const fn saturating_mul(self, rhs: i8) -> Self
pub const fn saturating_mul(self, rhs: i8) -> Self
Saturating integer multiplication.
Sourcepub const fn wrapping_mul(self, rhs: i8) -> Self
pub const fn wrapping_mul(self, rhs: i8) -> Self
Wrapping (modular) integer multiplication.
Sourcepub const fn checked_div(self, rhs: i8) -> Option<Self>
pub const fn checked_div(self, rhs: i8) -> Option<Self>
Checked integer division.
Returns None if the result would be out of range, or if rhs is zero.
Sourcepub const fn wrapping_div(self, rhs: i8) -> Self
pub const fn wrapping_div(self, rhs: i8) -> Self
Wrapping (modular) integer division.
Sourcepub const fn checked_div_euclid(self, rhs: i8) -> Option<Self>
pub const fn checked_div_euclid(self, rhs: i8) -> Option<Self>
Checked Euclidean division.
Returns None if the result would be out of range, or if rhs is zero.
Sourcepub const fn wrapping_div_euclid(self, rhs: i8) -> Self
pub const fn wrapping_div_euclid(self, rhs: i8) -> Self
Wrapping (modular) Euclidean division.
Sourcepub const fn checked_rem(self, rhs: i8) -> Option<Self>
pub const fn checked_rem(self, rhs: i8) -> Option<Self>
Checked integer remainder.
Returns None if the result would be out of range, or if rhs is zero.
Sourcepub const fn wrapping_rem(self, rhs: i8) -> Self
pub const fn wrapping_rem(self, rhs: i8) -> Self
Wrapping (modular) integer remainder.
Sourcepub const fn checked_rem_euclid(self, rhs: i8) -> Option<Self>
pub const fn checked_rem_euclid(self, rhs: i8) -> Option<Self>
Checked Euclidean remainder.
Returns None if the result would be out of range, or if rhs is zero.
Sourcepub const fn wrapping_rem_euclid(self, rhs: i8) -> Self
pub const fn wrapping_rem_euclid(self, rhs: i8) -> Self
Wrapping (modular) Euclidean remainder.
Sourcepub const fn checked_neg(self) -> Option<Self>
pub const fn checked_neg(self) -> Option<Self>
Checked negation.
Returns None if the result would be out of range.
Sourcepub const fn saturating_neg(self) -> Self
pub const fn saturating_neg(self) -> Self
Saturating negation.
Sourcepub const fn wrapping_neg(self) -> Self
pub const fn wrapping_neg(self) -> Self
Wrapping (modular) negation.
Sourcepub const fn checked_abs(self) -> Option<Self>
pub const fn checked_abs(self) -> Option<Self>
Checked absolute value.
Sourcepub const fn saturating_abs(self) -> Self
pub const fn saturating_abs(self) -> Self
Saturating absolute value.
Sourcepub const fn wrapping_abs(self) -> Self
pub const fn wrapping_abs(self) -> Self
Wrapping (modular) absolute value.
Sourcepub const fn checked_pow(self, rhs: u32) -> Option<Self>
pub const fn checked_pow(self, rhs: u32) -> Option<Self>
Checked exponentiation.
Sourcepub const fn saturating_pow(self, rhs: u32) -> Self
pub const fn saturating_pow(self, rhs: u32) -> Self
Saturating exponentiation.
Sourcepub const fn wrapping_pow(self, exp: u32) -> Self
pub const fn wrapping_pow(self, exp: u32) -> Self
Wrapping (modular) exponentiation.
Sourcepub const fn checked_shl(self, rhs: u32) -> Option<Self>
pub const fn checked_shl(self, rhs: u32) -> Option<Self>
Checked shift left.
Sourcepub const fn checked_shr(self, rhs: u32) -> Option<Self>
pub const fn checked_shr(self, rhs: u32) -> Option<Self>
Checked shift right.