BoundedU16

Struct BoundedU16 

pub struct BoundedU16<const MIN: u16, const MAX: u16>(/* private fields */);
An u16 constrained to be in the range MIN..=MAX.

Implementations

Source

impl<const MIN: u16, const MAX: u16> BoundedU16<MIN, MAX>

pub const MIN_VALUE: u16 = MIN

The smallest value this bounded integer can contain.

pub const MAX_VALUE: u16 = MAX

The largest value that this bounded integer can contain.

pub const MIN: Self

The smallest value of the bounded integer.

pub const MAX: Self

The largest value of the bounded integer.

pub const fn new(n: u16) -> Option<Self>

Creates a bounded integer if the given value is within the range [MIN, MAX].

pub const fn const_new<const N: u16>() -> Self

Creates a bounded integer whose value is known at compile time.

Causes a compile-time error if N is not in the valid range.

pub const fn new_ref(n: &u16) -> Option<&Self>

Creates a reference to a bounded integer from a reference to a primitive if the given value is within the range [MIN, MAX].

pub const fn new_mut(n: &mut u16) -> Option<&mut Self>

Creates a mutable reference to a bounded integer from a mutable reference to a primitive if the given value is within the range [MIN, MAX].

pub const unsafe fn new_unchecked(n: u16) -> Self

Creates a bounded integer without checking the value.

Safety

The value must not be outside the valid range of values; it must not be less than MIN_VALUE or greater than MAX_VALUE.

pub const unsafe fn new_ref_unchecked(n: &u16) -> &Self

Creates a shared reference to a bounded integer from a shared reference to a primitive.

Safety

The value must not be outside the valid range of values; it must not be less than MIN_VALUE or greater than MAX_VALUE.

pub const unsafe fn new_mut_unchecked(n: &mut u16) -> &mut Self

Creates a mutable reference to a bounded integer from a mutable reference to a primitive.

Safety

The value must not be outside the valid range of values; it must not be less than MIN_VALUE or greater than MAX_VALUE.

pub const fn in_range(n: u16) -> bool

Checks whether the given value is in the range of the bounded integer.

pub const fn new_saturating(n: u16) -> Self

Creates a bounded integer by setting the value to MIN or MAX if it is too low or too high respectively.

pub const fn new_wrapping<__Z: LargerInt>(n: __Z) -> Self

Creates a bounded integer by wrapping using modular arithmetic.

For n in range, this is an identity function, and it wraps for n out of range.

The type parameter Z must be any integer type that is a superset of this one.

pub const fn from_str_radix(src: &str, radix: u32) -> Result<Self, ParseError>

Converts a string slice in a given base to the bounded integer.

Panics

Panics if radix is below 2 or above 36.

pub const fn get(self) -> u16

Returns the value of the bounded integer as a primitive type.

pub const fn get_ref(&self) -> &u16

Returns a shared reference to the value of the bounded integer.

pub const unsafe fn get_mut(&mut self) -> &mut u16

Returns a mutable reference to the value of the bounded integer.

Safety

This value must never be set to a value beyond the range of the bounded integer.

pub const fn pow(self, exp: u32) -> Self

Raises self to the power of exp, using exponentiation by squaring. Panics if it is out of range.

pub const fn div_euclid(self, rhs: u16) -> Self

Calculates the quotient of Euclidean division of self by rhs. Panics if rhs is 0 or the result is out of range.

pub const fn rem_euclid(self, rhs: u16) -> Self

Calculates the least nonnegative remainder of self (mod rhs). Panics if rhs is 0 or the result is out of range.

pub const fn checked_add(self, rhs: u16) -> Option<Self>

Checked integer addition.

Returns None if the result would be out of range.

pub const fn saturating_add(self, rhs: u16) -> Self

Saturating integer addition.

pub const fn wrapping_add(self, rhs: u16) -> Self

Wrapping (modular) integer addition.

pub const fn checked_sub(self, rhs: u16) -> Option<Self>

Checked integer subtraction.

Returns None if the result would be out of range.

pub const fn saturating_sub(self, rhs: u16) -> Self

Saturating integer subtraction.

pub const fn wrapping_sub(self, rhs: u16) -> Self

Wrapping (modular) integer subtraction.

pub const fn checked_mul(self, rhs: u16) -> Option<Self>

Checked integer multiplication.

Returns None if the result would be out of range.

pub const fn saturating_mul(self, rhs: u16) -> Self

Saturating integer multiplication.

pub const fn wrapping_mul(self, rhs: u16) -> Self

Wrapping (modular) integer multiplication.

pub const fn checked_div(self, rhs: u16) -> Option<Self>

Checked integer division.

Returns None if the result would be out of range, or if rhs is zero.

pub const fn wrapping_div(self, rhs: u16) -> Self

Wrapping (modular) integer division.

pub const fn checked_div_euclid(self, rhs: u16) -> Option<Self>

Checked Euclidean division.

Returns None if the result would be out of range, or if rhs is zero.

pub const fn wrapping_div_euclid(self, rhs: u16) -> Self

Wrapping (modular) Euclidean division.

pub const fn checked_rem(self, rhs: u16) -> Option<Self>

Checked integer remainder.

Returns None if the result would be out of range, or if rhs is zero.

pub const fn wrapping_rem(self, rhs: u16) -> Self

Wrapping (modular) integer remainder.

pub const fn checked_rem_euclid(self, rhs: u16) -> Option<Self>

Checked Euclidean remainder.

Returns None if the result would be out of range, or if rhs is zero.

pub const fn wrapping_rem_euclid(self, rhs: u16) -> Self

Wrapping (modular) Euclidean remainder.

pub const fn checked_neg(self) -> Option<Self>

Checked negation.

Returns None if the result would be out of range.

pub const fn checked_pow(self, rhs: u32) -> Option<Self>

Checked exponentiation.

pub const fn saturating_pow(self, rhs: u32) -> Self

Saturating exponentiation.

pub const fn wrapping_pow(self, exp: u32) -> Self

Wrapping (modular) exponentiation.

pub const fn checked_shl(self, rhs: u32) -> Option<Self>

Checked shift left.

pub const fn checked_shr(self, rhs: u32) -> Option<Self>

Checked shift right.